LLMcollection is a collection of open source LLMs implemented from scratch in pytorch. The accompanied code and documentation is present in **[this](https://github.com/mohitpg/LLMs-from-scratch)** github repo.

